@@ -12,6 +12,4 @@ class on_taxable_income(Variable):
     def formula(person, period, parameters):
         province = person.household("province", period)
         in_ontario = province == province.possible_values.ONTARIO
-        return in_ontario * add(
-            person, period, ["total_individual_pre_tax_income"]
-        )
+        return in_ontario * person("total_individual_pre_tax_income", period)
